@@ -59,6 +59,8 @@ class Config(object):
     y_label_rotation = 0
     #: Set to false to remove legend
     show_legend = True
+    #: Set to true to position legend at bottom
+    legend_at_bottom = False
     #: Set to false to remove dots
     show_dots = True
     #: Size of legend boxes
@@ -87,6 +89,8 @@ class Config(object):
     interpolate = None
     #: Number of interpolated points between two values
     interpolation_precision = 250
+    #: Explicitly specify min and max of values (ie: (0, 100))
+    range = None
     #: Set the ordinate zero value (for filling)
     zero = 0
     #: Text to display when no data is given
@@ -102,6 +106,12 @@ class Config(object):
     disable_xml_declaration = False
     #: Write width and height attributes
     explicit_size = False
+    #: Legend string length truncation threshold (None = auto)
+    truncate_legend = None
+    #: Label string length truncation threshold (None = auto)
+    truncate_label = None
+    #: Pretty print the svg
+    pretty_print = False
 
     def __init__(self, **kwargs):
         """Can be instanciated with config kwargs"""
