@@ -25,8 +25,8 @@ from __future__ import division
 from pygal.interpolate import interpolation
 from pygal.graph.base import BaseGraph
 from pygal.view import View, LogView
-from pygal.util import is_major
-from math import isnan, pi
+from pygal.util import is_major, truncate, reverse_text_len
+from math import isnan, pi, sqrt, floor, ceil
 
 
 class Graph(BaseGraph):
@@ -104,6 +104,18 @@ class Graph(BaseGraph):
             return
 
         axis = self.svg.node(self.nodes['plot'], class_="axis x")
+        truncation = self.truncate_label
+        if not truncation:
+            if self.x_label_rotation or len(self._x_labels) <= 1:
+                truncation = 25
+            else:
+                first_label_position = self.view.x(self._x_labels[0][1])
+                last_label_position = self.view.x(self._x_labels[-1][1])
+                available_space = (
+                    last_label_position - first_label_position) / (
+                        len(self._x_labels) - 1)
+                truncation = int(
+                    reverse_text_len(available_space, self.label_font_size))
 
         if 0 not in [label[1] for label in self._x_labels] and draw_axes:
             self.svg.node(axis, 'path',
@@ -123,7 +135,9 @@ class Graph(BaseGraph):
                              x=x,
                              y=y + .5 * self.label_font_size + 5
             )
-            text.text = label
+            text.text = truncate(label, truncation)
+            if text.text != label:
+                self.svg.node(guides, 'title').text = label
             if self.x_label_rotation:
                 text.attrib['transform'] = "rotate(%d %f %f)" % (
                     self.x_label_rotation, x, y)
@@ -167,52 +181,82 @@ class Graph(BaseGraph):
         """Make the legend box"""
         if not self.show_legend:
             return
+        truncation = self.truncate_legend
+        if self.legend_at_bottom:
+            x = self.margin.left + 10
+            y = (self.margin.top + self.view.height +
+                 self._x_labels_height + 10)
+            cols = ceil(sqrt(len(self.series)))
+
+            if not truncation:
+                available_space = self.view.width / cols - (
+                    self.legend_box_size + 5)
+                truncation = int(reverse_text_len(
+                    available_space, self.legend_font_size))
+        else:
+            x = self.margin.left + self.view.width + 10
+            y = self.margin.top + 10
+            cols = 1
+            if not truncation:
+                truncation = 15
+
         legends = self.svg.node(
             self.nodes['graph'], class_='legends',
-            transform='translate(%d, %d)' % (
-                self.margin.left + self.view.width + 10,
-                self.margin.top + 10))
+            transform='translate(%d, %d)' % (x, y))
+
+        h = max(self.legend_box_size, self.legend_font_size)
+        x_step = self.view.width / cols
         for i, title in enumerate(self._legends):
+            col = i % cols
+            row = i // cols
+
             legend = self.svg.node(
                 legends, class_='legend reactive activate-serie',
                 id="activate-serie-%d" % i)
             self.svg.node(
                 legend, 'rect',
-                x=0,
-                y=1.5 * i * self.legend_box_size,
+                x=col * x_step,
+                y=1.5 * row * h + (
+                    self.legend_font_size - self.legend_box_size
+                    if self.legend_font_size > self.legend_box_size else 0
+                ) / 2,
                 width=self.legend_box_size,
                 height=self.legend_box_size,
-                class_="color-%d reactive" % i
-            ).text = title
+                class_="color-%d reactive" % (i % 16)
+            )
+            truncated = truncate(title, truncation)
             # Serious magical numbers here
             self.svg.node(
                 legend, 'text',
-                x=self.legend_box_size + 5,
-                y=1.5 * i * self.legend_box_size
-                + .5 * self.legend_box_size
+                x=col * x_step + self.legend_box_size + 5,
+                y=1.5 * row * h
+                + .5 * h
                 + .3 * self.legend_font_size
-            ).text = title
+            ).text = truncated
+            if truncated != title:
+                self.svg.node(legend, 'title').text = title
 
     def _title(self):
         """Make the title"""
         if self.title:
             self.svg.node(self.nodes['graph'], 'text', class_='title',
-                      x=self.margin.left + self.view.width / 2,
-                      y=self.title_font_size + 10
-            ).text = self.title
+                          x=self.margin.left + self.view.width / 2,
+                          y=self.title_font_size + 10
+                      ).text = truncate(self.title, int(reverse_text_len(
+                          self.width, self.title_font_size)))
 
     def _serie(self, serie):
         """Make serie node"""
         return dict(
             plot=self.svg.node(
                 self.nodes['plot'],
-                class_='series serie-%d color-%d' % (serie, serie)),
+                class_='series serie-%d color-%d' % (serie, serie % 16)),
             overlay=self.svg.node(
                 self.nodes['overlay'],
-                class_='series serie-%d color-%d' % (serie, serie)),
+                class_='series serie-%d color-%d' % (serie, serie % 16)),
             text_overlay=self.svg.node(
                 self.nodes['text_overlay'],
-                class_='series serie-%d color-%d' % (serie, serie)))
+                class_='series serie-%d color-%d' % (serie, serie % 16)))
 
     def _interpolate(self, ys, xs,
                    polar=False, xy=False, xy_xmin=None, xy_rng=None):
